@@ -18,7 +18,7 @@ from libs import bflb_utils
 from libs import bflb_eflash_loader
 from libs import bflb_toml as toml
 from libs import bflb_flash_select
-from libs.bflb_utils import verify_hex_num, get_eflash_loader, get_serial_ports
+from libs.bflb_utils import verify_hex_num, get_eflash_loader, get_serial_ports, convert_path
 from libs.bflb_configobj import BFConfigParser
 import libs.bflb_pt_creater as partition
 import libs.bflb_eflash_loader as eflash_loader
@@ -517,8 +517,8 @@ class BflbIotTool(object):
             efusemaskfile = img_cfg.get("Img_Cfg", "efuse_mask_file")
             cfg = BFConfigParser()
             cfg.read(self.eflash_loader_cfg)
-            cfg.set('EFUSE_CFG', 'file', os.path.relpath(efusefile, app_path).replace("\\", "/"))
-            cfg.set('EFUSE_CFG', 'maskfile', os.path.relpath(efusemaskfile, app_path).replace("\\", "/"))
+            cfg.set('EFUSE_CFG', 'file', convert_path(os.path.relpath(efusefile, app_path)))
+            cfg.set('EFUSE_CFG', 'maskfile', convert_path(os.path.relpath(efusemaskfile, app_path)))
             cfg.write(self.eflash_loader_cfg, 'w')
             self.efuse_load_en = True
         else:
@@ -1154,6 +1154,9 @@ def iot_download_cmd(args):
     else:
         bflb_utils.printf("Chip type is not in bl60x/bl602/bl702")
         return
+    
+    if config["param"]["interface_type"].lower() == "jlink" and args.baudrate > 12000:
+        config["param"]["speed_jlink"] = "12000"
                   
     if args.build:
         act = "build"
